@ECHO OFF
REM
REM \ldsu\bin\do_change.bat - script to do a single LDSU changes export
REM
REM	Changes are generated by comparing what's in the Directory now and what
REM	was in the Directory the last time LDSU ran. This method uses metafiles.
REM
REM	P1 - Name of export subdirectory (e.g. export_xxx )
REM	P2 - Name of foreign directory add file (e.g. xfer_out\xxx.add )
REM	P3 - Name of foreign directory del file (e.g. xfer_out\xxx.del )
REM	P4 - Name of foreign directory mod file (e.g. xfer_out\xxx.mod )
REM	  (P2,P3,P4 are Optional - changes not copied anywhere if not specified)
REM	P5 - Optional name for ldsu_config.dat in subdirectory
REM
REM	The following files must already exist in the export subdirectory:
REM
REM		ldsu_config.dat
REM		export_add.rdf, export_del.rdf, export_mod.rdf (mod is optional)
REM
REM	The following files are optional in the export subdirectory:
REM
REM		export_post.bat - procedure to process export_*.txt (possibly to
REM			convert to P2,P3,P4).  If procedure doesn't exist,
REM			export_*.txt is simply copied to P2,P3,P4 (if specified)
REM 
REM	The following files are created as a result of running this procedure:
REM
REM		export_add.txt - add changes. May be Converted or Copied to 'P2'
REM		export_del.txt - del changes. May be Converted or Copied to 'P3'
REM		export_mod.txt - mod changes. May be Converted or Copied to 'P4'
REM		ldsu.log - full LDSU stdout log
REM		export.log - changes log file (also copied to logs\'P1'.log)
REM		export.old - old metafile (from last run)
REM		export.new - new metafile
REM		export.start - changes-to-be-processed file
REM		export.finish - changes-were-processed file
REM
REM Each Changes export creates a "changes-to-be-processed" file. (export.start)
REM When the export_*.txt are successfully used by the post processor or the
REM foreign directory's local import procedure, this file should be renamed to
REM a "changes-were-processed" file (export.finish) by that procedure. 
REM

IF NOT DEFINED ldsubindir SET ldsubindir=%~dp0%

IF "%1"=="" GOTO USAGE
IF %1=="" GOTO USAGE
GOTO L1
:USAGE
ECHO Usage: %0 ldsu_subdirectory_name [xfer_out_add] [xfer_out_del] [xfer_out_mod] [config_file]
SET ldsu_status=1
GOTO LEND1
:L1
ECHO ----------------------------------------------------------------------
%ldsubindir%timestamp "%1 started at" 1

REM	set default directory to the export subdirectory

PUSHD %1
IF NOT errorlevel 1 GOTO L2
ECHO LDSU CHANGES EXPORT Failed - Invalid Subdirectory: %1
SET ldsu_status=1
GOTO LEND1
:L2

REM   At this point, if the "to-be-processed" file exists, then the last set of
REM   changes weren't used. If the "processed" file exists, then they were used.

IF NOT EXIST export.start GOTO L3
ECHO *** Warning ***, previous changes for %1 were not used
ECHO                  regenerating changes
GOTO L5
:L3
IF NOT EXIST export.finish GOTO L4
CALL %ldsubindir%do_archive export.old
MOVE export.new export.old >nul
MOVE export.finish export.start >nul
GOTO L5
:L4
ECHO >nul 2> export.old
ECHO >nul 2> export.start
:L5

REM	Run LDSU to export the changes data

ECHO exporting export_*.txt from Directory
CALL %ldsubindir%do_ldsu CHANGES %5

REM	If LDSU failed, send mail to administrator

IF %ldsu_status%==0 GOTO L6
ECHO LDSU CHANGES EXPORT Failed
CALL %ldsubindir%do_send_mail ldsu.log "%1 failure"
GOTO L11
:L6

REM	Else run the post processor script or copy the files (if specified)

set ldsu_add_file=..\%2
if %ldsu_add_file%==..\"" set ldsu_add_file=..\
if %ldsu_add_file%==..\ set ldsu_add_file=""
set ldsu_del_file=..\%3
if %ldsu_del_file%==..\"" set ldsu_del_file=..\
if %ldsu_del_file%==..\ set ldsu_del_file=""
set ldsu_mod_file=..\%4
if %ldsu_mod_file%==..\"" set ldsu_mod_file=..\
if %ldsu_mod_file%==..\ set ldsu_mod_file=""

IF NOT EXIST export_post.bat GOTO L7
SET ldsu_status=0
CALL export_post export_add.txt export_del.txt export_mod.txt %ldsu_add_file% %ldsu_del_file% %ldsu_mod_file%
IF %ldsu_status%==0 GOTO L10
ECHO LDSU CHANGES EXPORT Failed - Error Running EXPORT_POST
ECHO Error Running EXPORT_POST > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND
:L7
IF %ldsu_add_file%=="" GOTO L8
ECHO copying export_add.txt to %ldsu_add_file%
COPY export_add.txt %ldsu_add_file% >nul
IF NOT errorlevel 1 GOTO L8
ECHO LDSU EXPORT Changes Failed - Error copying export_add.txt to %ldsu_add_file%
ECHO Error copying export_add.txt to %ldsu_add_file% > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND
:L8
IF %ldsu_del_file%=="" GOTO L9
ECHO copying export_del.txt to %ldsu_del_file%
COPY export_del.txt %ldsu_del_file% >nul
IF NOT errorlevel 1 GOTO L9
ECHO LDSU EXPORT Changes Failed - Error copying export_del.txt to %ldsu_del_file%
ECHO Error copying export_del.txt to %ldsu_del_file% > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND
:L9
IF %ldsu_mod_file%=="" GOTO L10
ECHO copying export_mod.txt to %ldsu_mod_file%
COPY export_mod.txt %ldsu_mod_file% >nul
IF NOT errorlevel 1 GOTO L10
ECHO LDSU EXPORT Changes Failed - Error copying export_mod.txt to %ldsu_mod_file%
ECHO Error copying export_mod.txt to %ldsu_mod_file% > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND
:L10

REM	Copy the changes log to the logs directory

IF NOT EXIST export.log GOTO L11
IF NOT EXIST ..\logs GOTO L11
CALL %ldsubindir%do_archive ..\logs\%1.log
COPY export.log ..\logs\%1.log >nul
:L11

%ldsubindir%timestamp "%1 finished at" 0
ECHO ----------------------------------------------------------------------

:LEND
POPD
:LEND1
