@ECHO OFF
REM
REM \ldsu\bin\do_change1.bat - script to do a single LDSU changes export
REM
REM	Changes are generated by comparing what's in the Directory now against
REM	a foreign directory import file.
REM
REM	P1 - Name of export subdirectory (e.g. export_xxx )
REM	P2 - Name of foreign directory import file (e.g. xfer_in\xxx.dat
REM	  (P2 is optional - assume file in place if not specified)
REM	P3 - Name of foreign directory add file (e.g. xfer_out\xxx.add )
REM	P4 - Name of foreign directory del file (e.g. xfer_out\xxx.del )
REM	P5 - Name of foreign directory mod file (e.g. xfer_out\xxx.mod )
REM	  (P3,P4,P5 are Optional - changes not copied anywhere if not specified)
REM	P6 - Optional name for ldsu_config.dat in subdirectory
REM
REM	The following files must already exist in the export subdirectory:
REM
REM		ldsu_config.dat
REM		export_add.rdf, export_del.rdf, export_mod.rdf (mod is optional)
REM		export_input.rdf - foreign directory import (old) rdf file
REM		export_input.txt - import (old) file. (if P2 not specified)
REM
REM	The following files are optional in the export subdirectory:
REM
REM		export_pre.bat - procedure to convert 'P2' to export_input.txt.
REM			If procedure doesn't exist, file is simply copied.
REM			Only used if 'P2' is specified.
REM		export_post.bat - procedure to process export_XXX.txt (possibly
REM			to convert to P3,P4,P5).  If procedure doesn't exist,
REM			export_XXX.txt simply copied to P3,P4,P5 (if specified)
REM
REM	The following files are created as a result of running this procedure:
REM
REM		export_input.txt - import file. Converted or Copied from 'P2'.
REM			(if P2 specified. If not, this file must already exist)
REM		export_add.txt - add changes. May be Converted or Copied to 'P3'
REM		export_del.txt - del changes. May be Converted or Copied to 'P4'
REM		export_mod.txt - mod changes. May be Converted or Copied to 'P5'
REM		ldsu.log - full LDSU stdout log
REM		export.log - changes log file (also copied to logs\'P1'.log)
REM

IF NOT DEFINED ldsubindir SET ldsubindir=%~dp0%

IF "%1"=="" GOTO USAGE
IF %1=="" GOTO USAGE
GOTO L1
:USAGE
ECHO Usage: %0 ldsu_subdirectory_name [xfer_in_file] [xfer_out_add] [xfer_out_del] [xfer_out_mod]
SET ldsu_status=1
GOTO LEND1
:L1
ECHO ----------------------------------------------------------------------
%ldsubindir%timestamp "%1 started at" 1

REM	set default directory to the export subdirectory

PUSHD %1
IF NOT errorlevel 1 GOTO L2
ECHO LDSU CHANGES EXPORT Failed - Invalid Subdirectory: %1
SET ldsu_status=1
GOTO LEND1
:L2

REM	If Specified, Convert or Copy the input file to the LDSU input format
REM	This File will be used to create the "OLD" Metafile

IF "%2"=="" GOTO L51
IF %2=="" GOTO L51
IF NOT EXIST ..\%2 GOTO L5
IF NOT EXIST export_pre.bat GOTO L4

:L3
SET ldsu_status=0
CALL export_pre ..\%2 export_input.txt
IF %ldsu_status%==0 GOTO L6
ECHO LDSU CHANGES EXPORT Failed - Error Running EXPORT_PRE
ECHO Error Running EXPORT_PRE > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND

:L4
ECHO copying ..\%2 to export_input.txt
COPY ..\%2 export_input.txt >nul
IF NOT errorlevel 1 GOTO L6
ECHO LDSU CHANGES EXPORT Failed - Error copying ..\%2 to export_input.txt
ECHO Error copying ..\%2 to export_input.txt > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND

:L5
ECHO LDSU CHANGES EXPORT Failed - ..\%2 file not found
ECHO ..\%2 file not found > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND

REM	Run LDSU to export the changes data

:L51
ECHO exporting export_*.txt from Directory
CALL %ldsubindir%do_ldsu CHANGES %6

REM	If LDSU failed, send mail to administrator

IF %ldsu_status%==0 GOTO L6
ECHO LDSU CHANGES EXPORT Failed
CALL %ldsubindir%do_send_mail ldsu.log "%1 failure"
GOTO L11
:L6

REM	Else run the post processor script or copy the files (if specified)

set ldsu_add_file=..\%3
if %ldsu_add_file%==..\"" set ldsu_add_file=..\
if %ldsu_add_file%==..\ set ldsu_add_file=""
set ldsu_del_file=..\%4
if %ldsu_del_file%==..\"" set ldsu_del_file=..\
if %ldsu_del_file%==..\ set ldsu_del_file=""
set ldsu_mod_file=..\%5
if %ldsu_mod_file%==..\"" set ldsu_mod_file=..\
if %ldsu_mod_file%==..\ set ldsu_mod_file=""

IF NOT EXIST export_post.bat GOTO L7
SET ldsu_status=0
CALL export_post export_add.txt export_del.txt export_mod.txt %ldsu_add_file% %ldsu_del_file% %ldsu_mod_file%
IF %ldsu_status%==0 GOTO L10
ECHO LDSU CHANGES EXPORT Failed - Error Running EXPORT_POST
ECHO Error Running EXPORT_POST > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND
:L7
IF %ldsu_add_file%=="" GOTO L8
ECHO copying export_add.txt to %ldsu_add_file%
COPY export_add.txt %ldsu_add_file% >nul
IF NOT errorlevel 1 GOTO L8
ECHO LDSU EXPORT Changes Failed - Error copying export_add.txt to %ldsu_add_file%
ECHO Error copying export_add.txt to %ldsu_add_file% > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND
:L8
IF %ldsu_del_file%=="" GOTO L9
ECHO copying export_del.txt to %ldsu_del_file%
COPY export_del.txt %ldsu_del_file% >nul
IF NOT errorlevel 1 GOTO L9
ECHO LDSU EXPORT Changes Failed - Error copying export_del.txt to %ldsu_del_file%
ECHO Error copying export_del.txt to %ldsu_del_file% > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND
:L9
IF %ldsu_mod_file%=="" GOTO L10
ECHO copying export_mod.txt to %ldsu_mod_file%
COPY export_mod.txt %ldsu_mod_file% >nul
IF NOT errorlevel 1 GOTO L10
ECHO LDSU EXPORT Changes Failed - Error copying export_mod.txt to %ldsu_mod_file%
ECHO Error copying export_mod.txt to %ldsu_mod_file% > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND
:L10

REM	Also, archive input file

IF "%2"=="" GOTO L105
IF %2=="" GOTO L105
CALL %ldsubindir%do_archive ..\%2
:L105

REM	Copy the changes log to the logs directory

IF NOT EXIST export.log GOTO L11
IF NOT EXIST ..\logs GOTO L11
CALL %ldsubindir%do_archive ..\logs\%1.log
COPY export.log ..\logs\%1.log >nul
:L11

%ldsubindir%timestamp "%1 finished at" 0
ECHO ----------------------------------------------------------------------

:LEND
POPD
:LEND1
