@ECHO OFF
REM
REM \ldsu\bin\do_export1.bat - script to do a single LDSU export
REM
REM	Directory records to export are generated from an input file
REM
REM	P1 - Name of export subdirectory (e.g. export_xxx )
REM	P2 - Name of input file containing list of entries to export
REM	     (Optional - assume file in place if not specified)
REM	P3 - Name of foreign directory export file (e.g. xfer_out\xxx.dat )
REM	     (Optional - export file not copied anywhere if not specified)
REM	P4 - Optional name for ldsu_config.dat in subdirectory
REM
REM	The following files must already exist in the export subdirectory:
REM
REM		ldsu_config.dat or P3
REM		export_input.rdf - input file rdf file
REM		export_input.txt - input file (if P2 not specified)
REM		export_output.rdf - export rdf file
REM
REM	The following files are created as a result of running this procedure:
REM
REM		export_input.txt - input file. Converted or Copied from 'P2'.
REM			(if P2 specified. If not, this file must already exist)
REM		export_output.txt - LDSU export file.
REM			May be Converted or Copied to 'P3'.
REM		ldsu.log - full LDSU stdout log
REM
REM	The following files are optional in the export subdirectory:
REM
REM		export_input_pre.bat - procedure to convert 'P2' to export_input.txt
REM			If procedure doesn't exist, file is simply copied.
REM			Only used if 'P2' is specified.
REM		export_output_post.bat - procedure to process export_output.txt
REM			(possibly to convert to 'P3').  If procedure doesn't
REM			exist, export_output.txt is simply copied to 'P3'
REM			(if specified)
REM

IF NOT DEFINED ldsubindir SET ldsubindir=%~dp0%

IF "%1"=="" GOTO USAGE
IF %1=="" GOTO USAGE
GOTO L1
:USAGE
ECHO Usage: %0 ldsu_subdirectory_name [xfer_in_file] [xfer_out_file] [config_file]
SET ldsu_status=1
GOTO LEND1
:L1
ECHO ----------------------------------------------------------------------
%ldsubindir%timestamp "%1 started at" 1

REM	set default directory to the export subdirectory

PUSHD %1
IF NOT errorlevel 1 GOTO L2
ECHO LDSU EXPORT Failed - Invalid Subdirectory: %1
SET ldsu_status=1
GOTO LEND1
:L2

REM	If Specified, Convert or Copy the input file to the LDSU input format

IF "%2"=="" GOTO L6
IF %2=="" GOTO L6
IF NOT EXIST ..\%2 GOTO L5
IF NOT EXIST export_input_pre.bat GOTO L4

:L3
SET ldsu_status=0
CALL export_input_pre ..\%2 export_input.txt
IF %ldsu_status%==0 GOTO L6
ECHO LDSU EXPORT Failed - Error Running EXPORT_INPUT_PRE
ECHO Error Running EXPORT_INPUT_PRE > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND

:L4
ECHO copying ..\%2 to export_input.txt
COPY ..\%2 export_input.txt >nul
IF NOT errorlevel 1 GOTO L6
ECHO LDSU EXPORT Failed - Error copying ..\%2 to export_input.txt
ECHO Error copying ..\%2 to export_input.txt > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND

:L5
ECHO LDSU EXPORT Failed - ..\%2 file not found
ECHO ..\%2 file not found > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND

REM	Run LDSU to export the data

:L6
ECHO exporting export_output.txt from Directory
CALL %ldsubindir%do_ldsu EXPORT %4

REM	If LDSU failed, send mail to administrator

IF %ldsu_status%==0 GOTO L7
ECHO LDSU EXPORT Failed
CALL %ldsubindir%do_send_mail ldsu.log "%1 failure"
GOTO L10
:L7

REM	Else run the post processor script or copy the file (if specified)

set ldsu_export_file=..\%3
if %ldsu_export_file%==..\"" set ldsu_export_file=..\
if %ldsu_export_file%==..\ set ldsu_export_file=""
IF NOT EXIST export_output_post.bat GOTO L8
SET ldsu_status=0
CALL export_output_post export_output.txt %ldsu_export_file%
IF %ldsu_status%==0 GOTO L9
ECHO LDSU EXPORT Failed - Error Running EXPORT_OUTPUT_POST
ECHO Error Running EXPORT_OUTPUT_POST > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND
:L8
IF %ldsu_export_file%=="" GOTO L9
ECHO copying export_output.txt to %ldsu_export_file%
COPY export_output.txt %ldsu_export_file% >nul
IF NOT errorlevel 1 GOTO L9
ECHO LDSU EXPORT Failed - Error copying export_output.txt to %ldsu_export_file%
ECHO Error copying export_output.txt to %ldsu_export_file% > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND
:L9
IF "%2"=="" GOTO L10
IF %2=="" GOTO L10
CALL %ldsubindir%do_archive ..\%2

:L10
%ldsubindir%timestamp "%1 finished at" 0
ECHO ----------------------------------------------------------------------

:LEND
POPD
:LEND1
