@ECHO OFF
REM
REM \ldsu\bin\do_trans.bat -script to do single LDSU transaction mode import
REM
REM	P1 - Name of import subdirectory (e.g. import_xxx )
REM	P2 - Name of foreign dir import ADD file (e.g. xfer_in\xxx_add.dat )
REM	P3 - Name of foreign dir import DEL file (e.g. xfer_in\xxx_del.dat )
REM	P4 - Name of foreign dir import MOD file (e.g. xfer_in\xxx_mod.dat )
REM		(P2,P3,P4 are all optional)
REM	P5 - Optional name for ldsu_config.dat in subdirectory
REM
REM	The following files must already exist in the import subdirectory:
REM
REM		ldsu_config.dat or P5
REM		import.rdf  OR (or name specified in config file)
REM			1-3 of import_add.rdf,import_del.rdf,import_mod.rdf
REM		import_add.txt - add import file. (if P2 not specified)
REM		import_del.txt - del import file. (if P3 not specified)
REM		import_mod.txt - mod import file. (if P4 not specified)
REM			(The import_*.txt files are only required if specified
REM			 in ldsu_config.dat. All three are not required.)
REM
REM	The following files are optional in the import subdirectory:
REM
REM		import_pre.bat - procedure to convert 'Pn' to import_xxx.txt.
REM			   If procedure doesn't exist, files are simply copied.
REM			   Only used if 'P2','P3', or 'P4' is specified.
REM
REM	The following files are created as a result of running this procedure:
REM
REM		import_add.txt - add import file. Converted or Copied from 'P2'.
REM			(if P2 specified. If not, this file must already exist)
REM		import_del.txt - del import file. Converted or Copied from 'P3'.
REM			(if P3 specified. If not, this file must already exist)
REM		import_mod.txt - mod import file. Converted or Copied from 'P4'.
REM			(if P4 specified. If not, this file must already exist)
REM		import.log - transaction log file (also copied to logs subdir.)
REM		ldsu.log - full LDSU stdout log
REM

IF NOT DEFINED ldsubindir SET ldsubindir=%~dp0%

IF "%1"=="" GOTO USAGE
IF %1=="" GOTO USAGE
GOTO L1
:USAGE
ECHO Usage: %0 ldsu_subdirectory_name [xfer_in_add] [xfer_in_del] [xfer_in_mod] [config_file]
SET ldsu_status=1
GOTO LEND1
:L1
ECHO ----------------------------------------------------------------------
%ldsubindir%timestamp "%1 started at" 1

REM	set default directory to the import subdirectory

PUSHD %1
IF NOT errorlevel 1 GOTO L2
ECHO LDSU IMPORT Failed - Invalid Subdirectory: %1
SET ldsu_status=1
GOTO LEND1
:L2

REM	If Specified, Convert or Copy the input files to the LDSU input format

set ldsu_add_file=..\%2
if %ldsu_add_file%==..\"" set ldsu_add_file=..\
if %ldsu_add_file%==..\ set ldsu_add_file=""
set ldsu_del_file=..\%3
if %ldsu_del_file%==..\"" set ldsu_del_file=..\
if %ldsu_del_file%==..\ set ldsu_del_file=""
set ldsu_mod_file=..\%4
if %ldsu_mod_file%==..\"" set ldsu_mod_file=..\
if %ldsu_mod_file%==..\ set ldsu_mod_file=""
IF NOT %ldsu_add_file%=="" GOTO L3
IF NOT %ldsu_del_file%=="" GOTO L4
IF NOT %ldsu_mod_file%=="" GOTO L5
GOTO L10
:L3
IF %ldsu_add_file%=="" GOTO L4
IF EXIST %ldsu_add_file% GOTO L4
ECHO LDSU IMPORT Failed - %ldsu_add_file% file not found
ECHO %ldsu_add_file% file not found > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND
:L4
IF %ldsu_del_file%=="" GOTO L5
IF EXIST %ldsu_del_file% GOTO L5
ECHO LDSU IMPORT Failed - %ldsu_del_file% file not found
ECHO %ldsu_del_file% file not found > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND
:L5
IF %ldsu_mod_file%=="" GOTO L6
IF EXIST %ldsu_mod_file% GOTO L6
ECHO LDSU IMPORT Failed - %ldsu_mod_file% file not found
ECHO %ldsu_mod_file% file not found > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND

:L6
SET ldsu_status=0
IF NOT EXIST import_pre.bat GOTO L7
CALL import_pre %ldsu_add_file% %ldsu_del_file% %ldsu_mod_file% import_add.txt import_del.txt import_mod.txt 
IF %ldsu_status%==0 GOTO L10
ECHO LDSU IMPORT Failed - Error Running IMPORT_PRE
ECHO Error Running IMPORT_PRE > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND

:L7
IF %ldsu_add_file%=="" GOTO L8
ECHO copying %ldsu_add_file% to import_add.txt
COPY %ldsu_add_file% import.txt >nul
IF NOT errorlevel 1 GOTO L8
ECHO LDSU IMPORT Failed - Error copying %ldsu_add_file% to import_add.txt
ECHO Error copying %ldsu_add_file% to import_add.txt > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND
:L8
IF %ldsu_del_file%=="" GOTO L9
ECHO copying %ldsu_del_file% to import_del.txt
COPY %ldsu_del_file% import.txt >nul
IF NOT errorlevel 1 GOTO L9
ECHO LDSU IMPORT Failed - Error copying %ldsu_del_file% to import_del.txt
ECHO Error copying %ldsu_del_file% to import_del.txt > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND
:L9
IF %ldsu_mod_file%=="" GOTO L10
ECHO copying %ldsu_mod_file% to import_mod.txt
COPY %ldsu_mod_file% import.txt >nul
IF NOT errorlevel 1 GOTO L10
ECHO LDSU IMPORT Failed - Error copying %ldsu_mod_file% to import_mod.txt
ECHO Error copying %ldsu_mod_file% to import_mod.txt > t.t
CALL %ldsubindir%do_send_mail  t.t "%1 failure"
DEL /Q t.t
SET ldsu_status=1
GOTO LEND

REM	Run LDSU to import the data

:L10
ECHO importing import_*.txt to Directory
CALL %ldsubindir%do_ldsu TRANSACTION %5

REM	If LDSU failed, send mail to administrator, else archive input files

IF %ldsu_status%==0 GOTO L11
ECHO LDSU IMPORT Failed
CALL %ldsubindir%do_send_mail ldsu.log "%1 failure"
GOTO L12
:L11
IF NOT %ldsu_add_file%=="" CALL %ldsubindir%do_archive %ldsu_add_file%
IF NOT %ldsu_del_file%=="" CALL %ldsubindir%do_archive %ldsu_del_file%
IF NOT %ldsu_mod_file%=="" CALL %ldsubindir%do_archive %ldsu_mod_file%
:L12

REM	Copy the transaction log to the logs directory

IF NOT EXIST import.log GOTO L13
IF NOT EXIST ..\logs GOTO L13
CALL %ldsubindir%do_archive ..\logs\%1.log
COPY import.log ..\logs\%1.log >nul
:L13

%ldsubindir%timestamp "%1 finished at" 0
ECHO ----------------------------------------------------------------------

:LEND
POPD
:LEND1
